#!/bin/bash

# Set default values for environment variables if they are not provided
LDAP_ROOTPASS=${LDAP_ROOTPASS:-123}
LDAP_ORGANISATION=${LDAP_ORGANISATION:-example}
LDAP_DOMAIN=${LDAP_DOMAIN:-exmaple.com}

# Function to handle SIGTERM
terminate() {
    echo "Termination signal received, shutting down slapd..."
    slapd_stop
    exit 0
}

# Function to start slapd in the background
slapd_start() {
    ulimit -n 1024
    slapd -h "ldap:/// ldapi:///" -u openldap -g openldap -d 1 &
    SLAPD_PID=$!
}

# Function to stop slapd
slapd_stop() {
    kill -TERM "$SLAPD_PID"
    wait "$SLAPD_PID"
}

# Set trap for SIGTERM
trap 'terminate' SIGTERM SIGINT

cat <<EOF | debconf-set-selections
slapd slapd/internal/generated_adminpw password ${LDAP_ROOTPASS}
slapd slapd/internal/adminpw password ${LDAP_ROOTPASS}
slapd slapd/password2 password ${LDAP_ROOTPASS}
slapd slapd/password1 password ${LDAP_ROOTPASS}
slapd slapd/domain string ${LDAP_DOMAIN}
slapd shared/organization string ${LDAP_ORGANISATION}
slapd slapd/purge_database boolean true
slapd slapd/move_old_database boolean true
slapd slapd/allow_ldap_v2 boolean false
slapd slapd/no_configuration boolean false
slapd slapd/dump_database select when needed
EOF

dpkg-reconfigure -f noninteractive slapd

# Start slapd in the background
slapd_start

# Keep the script running and wait for the slapd process
wait "$SLAPD_PID"
